@@ -55,7 +55,7 @@
 prscoring <- function(data, id, block, item, choice, ..., wide = FALSE) {
   
   # check data ----
-  get_checks(data, id, block, item, choice)
+  get_checks(data, id, block, item, choice, nonbibd = TRUE)
   
   # do for all ids ----
   out <- lapply(unique(data[[id]]), function(x) {
